@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 BEGIN {
-	our $VERSION = '0.1.7'; # VERSION
+	our $VERSION = 'v0.1.8'; # VERSION
 }
 use Moose;
 use namespace::autoclean;
@@ -100,7 +100,7 @@ Business::CyberSource::Request::DCC - CyberSource DCC Request Object
 
 =head1 VERSION
 
-version 0.1.7
+version v0.1.8
 
 =head1 DESCRIPTION
 
@@ -206,7 +206,7 @@ This attribute is required.
 
 Reader: credit_card
 
-Type: Str
+Type: MooseX::Types::CreditCard::CreditCard
 
 This attribute is required.
 
